'use client'
import { X } from "react-feather";
import { useEffect, useState } from "react";
import toast from 'react-hot-toast';
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { useOptionsConversation } from "@/feature/messenger/hooks/useOptionsConversation";
import { Button, Input, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader, Select, SelectItem, useDisclosure } from "@nextui-org/react";
import { useTranslation } from "@/hooks/useTranslation";

const TransferConversation = () => {

    //store handler
    const openModalTransfer = useHandleConversationStore(state => state.openModalTransfer);
    const handleOpenModalTransfer = useHandleConversationStore(state => state.actions.handleOpenModalTransfer);
    const selectedConversation = useHandleConversationStore(state => state.selectedConversation);
    const { trans } = useTranslation();

    useEffect(() => {
        if (openModalTransfer == true) {
            setSelectedValue([]);
        }
    }, [openModalTransfer])
    //hooks
    const { agentsLogged, loading, setLoading, handleSubmitTranferConversation } = useOptionsConversation(selectedConversation);
    const [selectedValue, setSelectedValue] = useState<string[]>([]);
    const [commentary, setCommentary] = useState('');

    const closeBtn = (
        <button className="close" onClick={() => handleOpenModalTransfer()}>
            <X size={20} />
        </button>
    );
    const handleRadioChange = (event: any) => {
        event.stopPropagation();
        setSelectedValue(event.target.value);
    };

    const handleSubmit = async () => {
        setLoading(true)
        if (selectedValue.length == 0) {
            setLoading(false);
            toast.error(trans("modal_conversations_transfer_message_alert_select_option_title"));
            return
        }
        if (commentary.trim() == '') {
            setLoading(false);
            toast.error(trans("modal_conversations_transfer_message_alert_add_comment_title"));
            return
        }
        await handleSubmitTranferConversation(selectedValue[0], commentary);
        if (loading == false) {
            setCommentary('');
            setSelectedValue([]);
            await handleOpenModalTransfer();
        }
    }

    return (
        <>
            <Modal isOpen={openModalTransfer} onOpenChange={() => handleOpenModalTransfer()}>
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader>{trans("modal_conversations_transfer_title")} {selectedConversation.sesion}</ModalHeader>
                            <ModalBody>
                                <Select 
                                    label={trans("modal_conversations_transfer_label_agent_logged")}
                                    selectionMode="single"
                                    color="primary"
                                    selectedKeys={selectedValue}
                                    value={selectedValue}
                                    onSelectionChange={(keys) => setSelectedValue(Array.from(keys as Set<string>))}
                                    name="select"
                                >
                                    {agentsLogged.map((item: any, index: number) => (
                                        <SelectItem key={item.iduser} value={item.iduser}>
                                            {item.login}
                                        </SelectItem>
                                    ))}
                                </Select>
                                <Input
                                    label={trans("modal_conversations_transfer_label_commentary")}
                                    name="text"
                                    type="textarea"
                                    value={commentary}
                                    onChange={(e) => setCommentary(e.target.value)}
                                />
                            </ModalBody>
                            <ModalFooter>
                                <Button color="danger" variant="light" isDisabled={loading} onPress={handleOpenModalTransfer}>
                                    {trans("modal_conversations_transfer_button_cancel_title")}
                                </Button>
                                <Button color="primary" isLoading={loading} onPress={handleSubmit}>
                                    {loading ? trans("modal_conversations_transfer_button_send_loading_title") : trans("modal_conversations_transfer_button_send_title")}
                                </Button>
                            </ModalFooter>
                        </>
                    )}
                </ModalContent>
            </Modal>
        </>
    )
}

export default TransferConversation